@@ -8,6 +8,9 @@
 #'                containing the columns 'id', 'lon', 'lat'
 #' @param mode string. Transport modes allowed for the trips. Defaults to
 #'             "WALK". See details for other options.
+#' @param mode_egress string. Transport mode used after egress from public
+#'                    transport. It can be either 'WALK', 'BICYCLE', or 'CAR'.
+#'                    Defaults to "WALK".
 #' @param departure_datetime POSIXct object. If working with public transport
 #'                           networks, please check \code{calendar.txt} within
 #'                           the GTFS file for valid dates.
@@ -100,6 +103,7 @@ travel_time_matrix <- function(r5r_core,
                                origins,
                                destinations,
                                mode = "WALK",
+                               mode_egress = "WALK",
                                departure_datetime = Sys.time(),
                                time_window = 1L,
                                percentiles = 50L,
@@ -131,7 +135,7 @@ travel_time_matrix <- function(r5r_core,
   checkmate::assert_class(r5r_core, "jobjRef")
 
   # modes
-  mode_list <- select_mode(mode)
+  mode_list <- select_mode(mode, mode_egress)
 
   # departure time
   departure <- posix_to_string(departure_datetime)
